<?php

namespace Drupal\rabbit_hole\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;
use Drupal\rabbit_hole\BehaviorSettingsInterface;

/**
 * Defines the Behavior settings entity.
 *
 * @ConfigEntityType(
 *   id = "behavior_settings",
 *   label = @Translation("Rabbit hole settings"),
 *   handlers = {},
 *   config_prefix = "behavior_settings",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *     "action" = "action"
 *   },
 *   config_export = {
 *     "id",
 *     "uuid",
 *     "targetEntityType",
 *     "bundle",
 *     "action",
 *     "no_bypass",
 *     "bypass_message",
 *     "configuration"
 *   },
 *   links = {}
 * )
 */
class BehaviorSettings extends ConfigEntityBase implements BehaviorSettingsInterface {

  /**
   * The Behavior settings ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The configured action (e.g. display_page).
   *
   * @var string
   */
  protected $action;

  /**
   * Entity type to be displayed.
   *
   * @var string
   */
  protected $targetEntityType;

  /**
   * Bundle to be displayed.
   *
   * @var string
   */
  protected $bundle;

  /**
   * The entity type id, eg. 'node_type'.
   *
   * @deprecated in rabbit_hole:2.0.0 and is removed from rabbit_hole:3.0.0.
   *   The 'entity_type_id' key can be removed from the configuration.
   * @see https://www.drupal.org/node/3374669
   *
   * @var string
   */
  protected $entity_type_id;

  /**
   * The entity id, eg. 'article'.
   *
   * @deprecated in rabbit_hole:2.0.0 and is removed from rabbit_hole:3.0.0.
   *   The 'entity_id' key can be removed from the configuration.
   * @see https://www.drupal.org/node/3374669
   *
   * @var string
   */
  protected $entity_id;

  /**
   * The bypass action.
   *
   * @var bool
   */
  protected $no_bypass;

  /**
   * The action-specific configuration.
   *
   * @var array
   */
  protected array $configuration = [];

  /**
   * {@inheritdoc}
   */
  public function setAction($action) {
    $this->action = $action;
  }

  /**
   * {@inheritdoc}
   */
  public function getAction() {
    return $this->action;
  }

  /**
   * {@inheritdoc}
   */
  public function setNoBypass(bool $no_bypass) {
    $this->no_bypass = $no_bypass;
  }

  /**
   * {@inheritdoc}
   */
  public function getNoBypass(): bool {
    return $this->no_bypass;
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    parent::calculateDependencies();

    if ($this->targetEntityType && $this->bundle) {
      // Create dependency on the bundle.
      $target_entity_type = $this->entityTypeManager()->getDefinition($this->targetEntityType);
      $bundle_config_dependency = $target_entity_type->getBundleConfigDependency($this->bundle);
      $this->addDependency($bundle_config_dependency['type'], $bundle_config_dependency['name']);
    }

    return $this;
  }

}
